@@ -151,6 +151,22 @@ private extension MediaLibraryService {
             assertionFailure("MediaLibraryService: Medialibrary failed to start.")
             return
         }
+
+        /* exclude Document directory from backup (QA1719) */
+        if let documentPath = NSSearchPathForDirectoriesInDomains(.documentDirectory, .userDomainMask, true).first {
+            var excludeURL = URL(fileURLWithPath: documentPath)
+            var resourceValue = URLResourceValues()
+            let excludeMediaLibrary = !UserDefaults.standard.bool(forKey: kVLCSettingBackupMediaLibrary)
+
+            resourceValue.isExcludedFromBackup = excludeMediaLibrary
+
+            do {
+                try excludeURL.setResourceValues(resourceValue)
+            } catch let error {
+                assertionFailure("MediaLibraryService: start: \(error.localizedDescription)")
+            }
+        }
+
         medialib.reload()
         medialib.discover(onEntryPoint: "file://" + path)
     }
@@ -385,7 +401,11 @@ extension MediaLibraryService {
         mlMedia.subtitleTrackIndex = Int64(player.indexOfCurrentSubtitleTrack)
         mlMedia.chapterIndex = Int64(player.indexOfCurrentChapter)
         mlMedia.titleIndex = Int64(player.indexOfCurrentTitle)
-        //create a new thumbnail
+
+        if mlMedia.type() == .video {
+            mlMedia.requestThumbnail(of: .thumbnail, desiredWidth: 320,
+                                     desiredHeight: 200, atPosition: player.playbackPosition)
+        }
     }
 }
 
@@ -426,8 +446,15 @@ extension MediaLibraryService {
 
 extension MediaLibraryService {
     func requestThumbnail(for media: VLCMLMedia) {
-        if media.isThumbnailGenerated() || media.thumbnail() != nil {
+        let thumbnailStatus = media.isThumbnailGenerated()
+
+        switch thumbnailStatus {
+        case .missing, .failure:
+            break
+        case .available, .persistentFailure, .crash:
             return
+        @unknown default:
+            assertionFailure("MediaLibraryService: requestThumbnail: Unknown thumbnail status.")
         }
 
         if !media.requestThumbnail(of: .thumbnail, desiredWidth: 320, desiredHeight: 200, atPosition: 0.03) {
@@ -475,17 +502,6 @@ extension MediaLibraryService: VLCMediaFileDiscovererDelegate {
         guard !isLoading else {
             return
         }
-        /* exclude media files from backup (QA1719) */
-        var excludeURL = URL(fileURLWithPath: filePath)
-        var resourceValue = URLResourceValues()
-
-        resourceValue.isExcludedFromBackup = true
-
-        do {
-            try excludeURL.setResourceValues(resourceValue)
-        } catch let error {
-            assertionFailure("MediaLibraryService: VLCMediaFileDiscovererDelegate: \(error.localizedDescription)")
-        }
 
         reload()
     }
