@@ -286,6 +286,7 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
 
         PlaybackService.sharedInstance().setPlayerHidden(editing)
 
+        searchBar.resignFirstResponder()
         searchBarConstraint?.constant = -self.searchBarSize
         reloadData()
     }
@@ -294,6 +295,10 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         if isEditing {
             tabBarController?.editToolBar()?.delegate = editController
             tabBarController?.displayEditToolbar(with: model)
+            UIView.animate(withDuration: 0.2) {
+                [weak self] in
+                self?.collectionView.contentInset = .zero
+            }
         } else {
             tabBarController?.hideEditToolbar()
         }
