@@ -12,7 +12,7 @@
 
 import UIKit
 
-class MediaViewController: VLCPagingViewController<VLCLabelCell>, MediaCategoryViewControllerDelegate {
+class MediaViewController: VLCPagingViewController<VLCLabelCell> {
 
     var services: Services
     private var rendererButton: UIButton
@@ -28,7 +28,7 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell>, MediaCategoryV
     private lazy var editButton: UIBarButtonItem = {
         var editButton = UIBarButtonItem(image: UIImage(named: "edit"),
                                      style: .plain, target: self,
-                                     action: #selector(customSetEditing(button:)))
+                                     action: #selector(customSetEditing))
         editButton.tintColor = PresentationTheme.current.colors.orangeUI
         editButton.accessibilityLabel = NSLocalizedString("BUTTON_EDIT", comment: "")
         editButton.accessibilityHint = NSLocalizedString("BUTTON_EDIT_HINT", comment: "")
@@ -36,17 +36,17 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell>, MediaCategoryV
     }()
 
     private lazy var doneButton: UIBarButtonItem = {
-        return UIBarButtonItem(barButtonSystemItem: .done, target: self, action: #selector(customSetEditing(button:)))
+        return UIBarButtonItem(barButtonSystemItem: .done, target: self, action: #selector(customSetEditing))
     }()
 
-    private var rigthBarButtons: [UIBarButtonItem]?
+    private var rightBarButtons: [UIBarButtonItem]?
     private var leftBarButton: UIBarButtonItem?
 
     init(services: Services) {
         self.services = services
         rendererButton = services.rendererDiscovererManager.setupRendererButton()
         super.init(nibName: nil, bundle: nil)
-        rigthBarButtons = [editButton, UIBarButtonItem(customView: rendererButton)]
+        rightBarButtons = [editButton, UIBarButtonItem(customView: rendererButton)]
         leftBarButton = sortButton
     }
 
@@ -87,17 +87,6 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell>, MediaCategoryV
         navigationController?.navigationBar.isTranslucent = false
         updateButtonsFor(viewControllers[currentIndex])
     }
-    // MARK: - MediaCatgoryViewControllerDelegate
-
-    func needsToUpdateNavigationbarIfNeeded(_ viewController: MediaCategoryViewController) {
-        if viewController == viewControllers[currentIndex] {
-            updateButtonsFor(viewController)
-        }
-    }
-
-    func enableCategorySwitching(for viewController: MediaCategoryViewController, enable: Bool) {
-        scrollingEnabled(enable)
-    }
 
     // MARK: - PagerTabStripDataSource
 
@@ -111,7 +100,7 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell>, MediaCategoryV
             !mediaCategoryViewController.isSearching {
             showButtons = true
         }
-        navigationItem.rightBarButtonItems = showButtons ? rigthBarButtons : nil
+        navigationItem.rightBarButtonItems = showButtons ? rightBarButtons : nil
         navigationItem.leftBarButtonItem = showButtons ? leftBarButton : nil
     }
 
@@ -132,13 +121,33 @@ class MediaViewController: VLCPagingViewController<VLCLabelCell>, MediaCategoryV
     }
 }
 
+// MARK: - MediaCatgoryViewControllerDelegate
+
+extension MediaViewController: MediaCategoryViewControllerDelegate {
+    func needsToUpdateNavigationbarIfNeeded(_ viewController: MediaCategoryViewController) {
+        if viewController == viewControllers[currentIndex] {
+            updateButtonsFor(viewController)
+        }
+    }
+
+    func enableCategorySwitching(for viewController: MediaCategoryViewController, enable: Bool) {
+        scrollingEnabled(enable)
+    }
+
+    func setEditingStateChanged(for viewController: MediaCategoryViewController, editing: Bool) {
+        customSetEditing()
+    }
+}
+
 // MARK: - Edit
 
 extension MediaViewController {
-    @objc private func customSetEditing(button: UIButton) {
+    @objc private func customSetEditing() {
         isEditing = !isEditing
-        rigthBarButtons = isEditing ? [doneButton] : [editButton, UIBarButtonItem(customView: rendererButton)]
+        rightBarButtons = isEditing ? [doneButton] : [editButton, UIBarButtonItem(customView: rendererButton)]
         leftBarButton = isEditing ? nil : sortButton
+        navigationItem.rightBarButtonItems = rightBarButtons
+        navigationItem.leftBarButtonItem = leftBarButton
     }
 
     override func setEditing(_ editing: Bool, animated: Bool) {
@@ -159,13 +168,8 @@ extension MediaViewController {
     }
 
     @objc func handleSortShortcut(sender: UILongPressGestureRecognizer) {
-        if sender.state == .began {
-            if #available(iOS 10.0, *) {
-                UIImpactFeedbackGenerator(style: .light).impactOccurred()
-            }
-            if let mediaCategoryViewController = viewControllers[currentIndex] as? MediaCategoryViewController {
-                mediaCategoryViewController.handleSortShortcut()
-            }
+        if let mediaCategoryViewController = viewControllers[currentIndex] as? MediaCategoryViewController {
+            mediaCategoryViewController.handleSortLongPress(sender: sender)
         }
     }
 }
