@@ -35,11 +35,15 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
     NSTimeInterval _startDL;
     NSString *_currentDownloadIdentifier;
 
+    NSLayoutConstraint *_contentViewHeight;
+
     VLCHTTPFileDownloader *_httpDownloader;
 
     WRRequestDownload *_FTPDownloadRequest;
     NSTimeInterval _lastStatsUpdate;
-    CGFloat _averageSpeed;
+    NSMutableArray *_lastSpeeds;
+    CGFloat _totalReceived;
+    CGFloat _lastReceived;
 
     UIBackgroundTaskIdentifier _backgroundTaskIdentifier;
 }
@@ -63,6 +67,7 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
 {
     self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
     if (self){
+        _lastSpeeds = [[NSMutableArray alloc] init];
         _currentDownloads = [[NSMutableArray alloc] init];
         _currentDownloadFilename = [[NSMutableArray alloc] init];
         [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(updateForTheme) name:kVLCThemeDidChangeNotification object:nil];
@@ -77,13 +82,19 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
 
     [self.downloadButton setTitle:NSLocalizedString(@"BUTTON_DOWNLOAD", nil) forState:UIControlStateNormal];
     [self.downloadButton setAccessibilityIdentifier:@"Download"];
+    self.downloadButton.layer.cornerRadius = 4.0;
     self.whatToDownloadHelpLabel.text = [NSString stringWithFormat:NSLocalizedString(@"DOWNLOAD_FROM_HTTP_HELP", nil), [[UIDevice currentDevice] model]];
     self.urlField.delegate = self;
     self.urlField.keyboardType = UIKeyboardTypeURL;
     self.progressContainer.hidden = YES;
     self.downloadsTable.hidden = YES;
+    self.downloadsTable.separatorStyle = UITableViewCellSeparatorStyleNone;
     self.whatToDownloadHelpLabel.backgroundColor = [UIColor clearColor];
 
+    _contentViewHeight = [_contentView.heightAnchor constraintEqualToConstant:0];
+    _contentViewHeight.active = YES;
+    [self updateContentViewHeightConstraint];
+
     self.edgesForExtendedLayout = UIRectEdgeNone;
     [self updateForTheme];
 }
@@ -105,17 +116,19 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
 {
     NSAttributedString *coloredAttributedPlaceholder = [[NSAttributedString alloc] initWithString:@"http://myserver.com/file.mkv" attributes:@{NSForegroundColorAttributeName: PresentationTheme.current.colors.lightTextColor}];
     self.urlField.attributedPlaceholder = coloredAttributedPlaceholder;
-    self.urlField.backgroundColor = PresentationTheme.current.colors.cellBackgroundB;
+    self.urlField.backgroundColor = PresentationTheme.current.colors.background;
     self.urlField.textColor = PresentationTheme.current.colors.cellTextColor;
+    self.urlBorder.backgroundColor = PresentationTheme.current.colors.mediaCategorySeparatorColor;
     self.downloadsTable.backgroundColor = PresentationTheme.current.colors.background;
     self.view.backgroundColor = PresentationTheme.current.colors.background;
     self.downloadButton.backgroundColor = PresentationTheme.current.colors.orangeUI;
     self.whatToDownloadHelpLabel.textColor = PresentationTheme.current.colors.lightTextColor;
-    self.progressContainer.backgroundColor = PresentationTheme.current.colors.cellBackgroundB;
-    self.currentDownloadLabel.textColor =  PresentationTheme.current.colors.cellBackgroundB;
-    self.progressPercent.textColor =  PresentationTheme.current.colors.cellBackgroundB;
-    self.speedRate.textColor =  PresentationTheme.current.colors.cellBackgroundB;
-    self.timeDL.textColor = PresentationTheme.current.colors.cellTextColor;
+    self.progressContainer.backgroundColor = PresentationTheme.current.colors.background;
+    self.currentDownloadLabel.textColor =  PresentationTheme.current.colors.cellTextColor;
+    self.progressPercent.textColor =  PresentationTheme.current.colors.cellDetailTextColor;
+    self.speedRate.textColor =  PresentationTheme.current.colors.cellDetailTextColor;
+    self.timeDL.textColor = PresentationTheme.current.colors.cellDetailTextColor;
+    self.progressView.progressTintColor = PresentationTheme.current.colors.orangeUI;
     [self.downloadsTable reloadData];
     [self setNeedsStatusBarAppearanceUpdate];
 }
@@ -162,6 +175,7 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
         [_currentDownloadFilename addObject:@""];
         self.urlField.text = @"";
         [self.downloadsTable reloadData];
+        [self updateContentViewHeightConstraint];
         [self _triggerNextDownload];
 
     }
@@ -169,8 +183,16 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
 
 - (void)_updateUI
 {
-    _currentDownloadType != VLCDownloadSchemeNone ? [self downloadStartedWithIdentifier:nil] : [self downloadEndedWithIdentifier:nil];
+    _currentDownloadType != VLCDownloadSchemeNone ? [self downloadStartedWithIdentifier:_currentDownloadIdentifier] : [self downloadEndedWithIdentifier:_currentDownloadIdentifier];
     [self.downloadsTable reloadData];
+    [self updateContentViewHeightConstraint];
+}
+
+- (void)updateContentViewHeightConstraint
+{
+    _contentViewHeight.constant = _downloadFieldContainer.frame.size.height
+                                    + _progressContainer.frame.size.height
+                                    + _downloadsTable.contentSize.height;
 }
 
 - (VLCHTTPFileDownloader *)httpDownloader
@@ -200,6 +222,10 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
     [_currentDownloadFilename removeObjectAtIndex:0];
     [self _beginBackgroundDownload];
     [self _updateUI];
+    _startDL = [NSDate timeIntervalSinceReferenceDate];
+    [_lastSpeeds removeAllObjects];
+    _lastReceived = 0;
+    _totalReceived = 0;
 }
 
 - (void)_downloadSchemeHttp
@@ -257,7 +283,6 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
         return;
     }
 
-    [self.activityIndicator startAnimating];
     NSString *downloadScheme = [_currentDownloads.firstObject scheme];
 
     if ([downloadScheme isEqualToString:@"http"] || [downloadScheme isEqualToString:@"https"]) {
@@ -290,7 +315,6 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
 - (void)downloadStartedWithIdentifier:(NSString *)identifier
 {
     _currentDownloadIdentifier = identifier;
-    [self.activityIndicator stopAnimating];
 
     VLCActivityManager *activityManager = [VLCActivityManager defaultManager];
     [activityManager networkActivityStopped];
@@ -301,7 +325,6 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
     [self.progressPercent setText:@"0%"];
     [self.speedRate setText:@"0 Kb/s"];
     [self.timeDL setText:@"00:00:00"];
-    _startDL = [NSDate timeIntervalSinceReferenceDate];
     self.progressContainer.hidden = NO;
 
     APLog(@"download started");
@@ -327,40 +350,57 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
 
 - (void)progressUpdatedTo:(CGFloat)percentage receivedDataSize:(CGFloat)receivedDataSize  expectedDownloadSize:(CGFloat)expectedDownloadSize identifier:(NSString *)identifier
 {
+    _totalReceived += receivedDataSize;
+    _lastReceived += receivedDataSize;
     if ((_lastStatsUpdate > 0 && ([NSDate timeIntervalSinceReferenceDate] - _lastStatsUpdate > .5)) || _lastStatsUpdate <= 0) {
+        CGFloat speed = [self getAverageSpeed:_lastReceived / ([NSDate timeIntervalSinceReferenceDate] - _lastStatsUpdate)];
         [self.progressPercent setText:[NSString stringWithFormat:@"%.1f%%", percentage*100]];
-        [self.timeDL setText:[self calculateRemainingTime:receivedDataSize expectedDownloadSize:expectedDownloadSize]];
-        [self.speedRate setText:[self calculateSpeedString:receivedDataSize]];
-            _lastStatsUpdate = [NSDate timeIntervalSinceReferenceDate];
+        [self.timeDL setText:[self getRemainingTimeString:speed expectedDownloadSize:expectedDownloadSize]];
+        [self.speedRate setText:[self getSpeedString:speed]];
+        _lastStatsUpdate = [NSDate timeIntervalSinceReferenceDate];
+        _lastReceived = 0;
     }
-
     [self.progressView setProgress:percentage animated:YES];
 }
 
-- (NSString*)calculateRemainingTime:(CGFloat)receivedDataSize expectedDownloadSize:(CGFloat)expectedDownloadSize
+- (CGFloat)getAverageSpeed:(CGFloat)speed
 {
-    CGFloat lastSpeed = receivedDataSize / ([NSDate timeIntervalSinceReferenceDate] - _startDL);
-    CGFloat smoothingFactor = 0.005;
-    _averageSpeed = isnan(_averageSpeed) ? lastSpeed : smoothingFactor * lastSpeed + (1 - smoothingFactor) * _averageSpeed;
-    CGFloat RemainingInSeconds = (expectedDownloadSize - receivedDataSize)/_averageSpeed;
+    [_lastSpeeds addObject:[NSNumber numberWithFloat:speed]];
+    if (_lastSpeeds.count > 10) {
+        [_lastSpeeds removeObjectAtIndex:0];
+    }
 
-    NSDate *date = [NSDate dateWithTimeIntervalSince1970:RemainingInSeconds];
+    CGFloat averageSpeed = 0;
+    int i = 0;
+    while (i < _lastSpeeds.count) {
+        averageSpeed += [_lastSpeeds[i] floatValue];
+        i += 1;
+    }
+    averageSpeed /= i;
+    return averageSpeed;
+}
+
+- (NSString *)getSpeedString:(CGFloat)speed
+{
+    NSString *string = [NSByteCountFormatter stringFromByteCount:speed
+                                                      countStyle:NSByteCountFormatterCountStyleDecimal];
+    string = [string stringByAppendingString:@"/s"];
+    return string;
+}
+
+- (NSString *)getRemainingTimeString:(CGFloat)speed expectedDownloadSize:(CGFloat)expectedDownloadSize
+{
+    CGFloat remainingInSeconds = (expectedDownloadSize - _totalReceived)/speed;
+
+    NSDate *date = [NSDate dateWithTimeIntervalSince1970:remainingInSeconds];
     NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
     [formatter setDateFormat:@"HH:mm:ss"];
     [formatter setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
 
-    NSString  *remaingTime = [formatter stringFromDate:date];
+    NSString *remaingTime = [formatter stringFromDate:date];
     return remaingTime;
 }
 
-- (NSString*)calculateSpeedString:(CGFloat)receivedDataSize
-{
-    CGFloat speed = receivedDataSize / ([NSDate timeIntervalSinceReferenceDate] - _startDL);
-    NSString *string = [NSByteCountFormatter stringFromByteCount:speed countStyle:NSByteCountFormatterCountStyleDecimal];
-    string = [string stringByAppendingString:@"/s"];
-    return string;
-}
-
 #pragma mark - ftp networking
 
 - (void)_downloadFTPFile:(NSURL *)URLToFile
@@ -420,8 +460,6 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
     UITableViewCell *cell = (UITableViewCell *)[tableView dequeueReusableCellWithIdentifier:CellIdentifier];
     if (cell == nil) {
         cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
-        cell.textLabel.textColor = PresentationTheme.current.colors.cellTextColor;
-        cell.detailTextLabel.textColor = PresentationTheme.current.colors.cellDetailTextColor;
     }
 
     NSInteger row = indexPath.row;
@@ -431,15 +469,22 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
         cell.textLabel.text = [[_currentDownloadFilename[row] lastPathComponent] stringByRemovingPercentEncoding];
 
     cell.detailTextLabel.text = [_currentDownloads[row] absoluteString];
+    cell.textLabel.textColor = PresentationTheme.current.colors.cellTextColor;
+    cell.detailTextLabel.textColor = PresentationTheme.current.colors.cellDetailTextColor;
 
     return cell;
 }
 
+- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
+{
+    return 60;
+}
+
 #pragma mark - table view delegate
 
 - (void)tableView:(UITableView *)tableView willDisplayCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath
 {
-    cell.backgroundColor = (indexPath.row % 2 == 0)? PresentationTheme.current.colors.cellBackgroundA : PresentationTheme.current.colors.cellBackgroundB;
+    cell.backgroundColor = PresentationTheme.current.colors.cellBackgroundA;
 }
 
 - (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
@@ -453,6 +498,7 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
         [_currentDownloads removeObjectAtIndex:indexPath.row];
         [_currentDownloadFilename removeObjectAtIndex:indexPath.row];
         [tableView reloadData];
+        [self updateContentViewHeightConstraint];
     }
 }
 
@@ -464,7 +510,9 @@ typedef NS_ENUM(NSUInteger, VLCDownloadScheme) {
         fileName = @"";
     [_currentDownloadFilename addObject:fileName];
     [self.downloadsTable reloadData];
-    [self _triggerNextDownload];
+    [self updateContentViewHeightConstraint];
+    if (_currentDownloadType == VLCDownloadSchemeNone)
+        [self _triggerNextDownload];
 }
 
 #pragma mark - text view delegate
