@@ -667,8 +667,7 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
             _sessionWillRestart = NO;
             [self stopPlayback];
         } break;
-        case VLCMediaPlayerStateEnded:
-        case VLCMediaPlayerStateStopped: {
+        case VLCMediaPlayerStateEnded: {
             NSInteger nextIndex = [self nextMediaIndex];
 
             if (nextIndex == -1) {
@@ -680,6 +679,17 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
                  postNotificationName:VLCPlaybackServicePlaybackMetadataDidChange object:self];
             }
         } break;
+        case VLCMediaPlayerStateStopped: {
+            [_listPlayer.mediaList lock];
+            NSUInteger listCount = _listPlayer.mediaList.count;
+            [_listPlayer.mediaList unlock];
+
+            if ([_listPlayer.mediaList indexOfMedia:_mediaPlayer.media] == listCount - 1
+                && self.repeatMode == VLCDoNotRepeat) {
+                _sessionWillRestart = NO;
+                [self stopPlayback];
+            }
+        } break;
         default:
             break;
     }
@@ -768,6 +778,11 @@ NSString *const VLCPlaybackServicePlaybackPositionUpdated = @"VLCPlaybackService
     NSInteger nextIndex = [self nextMediaIndex];
 
     if (nextIndex < 0) {
+        if (self.repeatMode == VLCRepeatAllItems) {
+            [_listPlayer next];
+            [[NSNotificationCenter defaultCenter]
+             postNotificationName:VLCPlaybackServicePlaybackMetadataDidChange object:self];
+        }
         return;
     }
 
